# Errors

- failed to resolve DisGeNet
- issue parsing Online Mendelian Inheritance in Man: Issue parsing OMIMGetter version Augu 23, 2024 with fmt %B %d, %Y
- failed to resolve Antibody Registry
- failed to resolve PathBank
- failed to resolve SwissLipids